@@ -1,9 +1,13 @@
 package Package::Stash::XS;
 BEGIN {
-  $Package::Stash::XS::VERSION = '0.23';
+  $Package::Stash::XS::AUTHORITY = 'cpan:DOY';
+}
+{
+  $Package::Stash::XS::VERSION = '0.26';
 }
 use strict;
 use warnings;
+use 5.008001;
 # ABSTRACT: faster and more correct implementation of the Package::Stash API
 
 use XSLoader;
@@ -21,6 +25,7 @@ XSLoader::load(
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -29,7 +34,7 @@ Package::Stash::XS - faster and more correct implementation of the Package::Stas
 
 =head1 VERSION
 
-version 0.23
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -41,21 +46,24 @@ This is a backend for L<Package::Stash>, which provides the functionality in a
 way that's less buggy and much faster. It will be used by default if it's
 installed, and should be preferred in all environments with a compiler.
 
-=head1 BUGS / CAVEATS
+=head1 BUGS
 
-=over 4
-
-=item * Prior to perl 5.10, scalar slots are only considered to exist if they are defined
-
-This is due to a shortcoming within perl itself. See
-L<perlref/Making References> point 7 for more information.
-
-=back
+No known bugs (but see the BUGS section in L<Package::Stash>).
 
 Please report any bugs through RT: email
 C<bug-package-stash-xs at rt.cpan.org>, or browse to
 L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Package-Stash-XS>.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<Class::MOP::Package>
+
+This module is a factoring out of code that used to live here
+
+=back
+
 =head1 SUPPORT
 
 You can find this documentation for this module with the perldoc command.
@@ -103,22 +111,15 @@ new
 remove_glob
 remove_symbol
 
-=head1 SEE ALSO
+=head1 AUTHOR
 
-=over 4
-
-=item * L<Class::MOP::Package>
-
-This module is a factoring out of code that used to live here
-
-=back
+Jesse Luehrs <doy at tozt dot net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jesse Luehrs.
+This software is copyright (c) 2013 by Jesse Luehrs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
